import { hasOnlyKeys, hasProperty } from "./validation";
import { isId, type Id } from "./Id";
import type { State } from "./State";

export interface GameData {
	isStarted: boolean;
	players: { id: Id; username: string }[];
	state: State;
}

export function isGameData(target: unknown): target is GameData {
	if (!hasProperty(target, "isStarted", "boolean")) {
		return false;
	}

	if ("players" in (target as any)) {
		const { players } = target as any;

		for (const player of players) {
			if (!isId(player.id)) {
				return false;
			}

			if (!hasProperty(player, "username", "string")) {
				return false;
			}
		}
	} else {
		return false;
	}

	// the user cannot update this property, they have to send it as it is, so if we
	// receive something that isn't a correctly formed state, that will get rejected
	// anyway (since it won't match what we already have).
	if (!hasProperty(target, "state", "object")) {
		return false;
	}

	return hasOnlyKeys(target, ["players", "isStarted", "state"]);
}
