import { hasOnlyKeys, hasProperty } from "$lib/validation";
import { isId, type Id } from "$lib/Id";

export interface Listing<T = unknown> {
	id: Id;
	createdAt: string;
	deleted: boolean;
	modifiedAt: string | null;
	data: T;
}

export function isListing<T>(
	target: unknown,
	dataGuard?: (target: unknown) => target is T,
): target is Listing<T> {
	if (!hasProperty(target, "id", isId)) return false;
	if (!hasProperty(target, "createdAt", "string")) return false;

	if (!hasProperty(target, "modifiedAt", "null")) {
		if (!hasProperty(target, "modifiedAt", "string")) return false;
	}

	if (!hasProperty(target, "deleted", "boolean")) return false;
	if (!hasProperty(target, "data", "object")) return false;

	if (!hasOnlyKeys(target, ["id", "createdAt", "modifiedAt", "deleted", "data"]))
		return false;

	return dataGuard?.((target as any)["data"]) ?? true;
}
