import { hash } from "bcrypt";
import { hasProperty, hasOnlyKeys } from "./validation";
import { BCRYPT_SALT_ROUNDS } from "$env/static/private";

const saltRounds = parseInt(BCRYPT_SALT_ROUNDS);

export interface LoginData {
	username: string;
	password: string;
	role: string;
}

export function isLoginData(target: unknown): target is LoginData {
	if (!hasProperty(target, "username", "string")) return false;
	if (!hasProperty(target, "password", "string")) return false;
	if (!hasProperty(target, "role", "string")) return false;
	return hasOnlyKeys(target, ["username", "password", "role"]);
}

export async function hashPassword(password: string): Promise<string> {
	return await hash(password, saltRounds);
}
