import { describe, it } from "vitest";
import { Game } from "$lib/server/Game";
import { deepEqual, ok, throws } from "node:assert/strict";
import { createId, idFromString, stringFromId } from "$lib/Id";
import { equal } from "node:assert";

describe("Game", () => {
	const idString = stringFromId(createId());
	describe("addPlayer", () => {
		it("should push a player id into the player array", () => {
			const game = new Game();
			deepEqual(game.players, []);

			game.addPlayer(idFromString(idString));
			equal(game.players.length, 1);
			equal(stringFromId(game.players[0]), idString);
		});
	});

	describe("start", () => {
		it("start shoud start the game", () => {
			const game = new Game();
			game.isStarted = false;

			game.start();
			ok(game.isStarted);
		});

		it("start should throw if the game is already started", () => {
			const game = new Game();

			game.start();
			throws(() => game.start());
		});
	});
});
