import { describe, it } from "vitest";
import { createNewListing, updateListing } from "../modifyListing";
import { Game } from "$lib/server/Game";
import { deepEqual, equal, ok } from "node:assert/strict";
import { isId } from "$lib/Id";

describe("modifyListing", () => {
	describe("createNewListing", () => {
		it("should create a new Listing with the provided data, and a new UUID", () => {
			const game = new Game();
			const listing = createNewListing(game);

			ok(listing.data instanceof Game);
			ok(listing.modifiedAt === null);
			ok(!listing.deleted);
			ok(isId(listing.id));
			equal(typeof listing.createdAt, "string");
		});
	});

	describe("updateListing", () => {
		it("should return a new listing with updated data and a modified date", () => {
			const game = new Game();
			const update = new Game();
			update.isStarted = !game.isStarted;

			const listing = createNewListing(game);
			const updatedListing = updateListing(listing, update);

			deepEqual(updatedListing.data, update);
			equal(typeof updatedListing.modifiedAt, "string");
		});
	});
});
