import { hashPassword, isLoginData, type LoginData } from "$lib/Login";
import { describe, expect, it } from "vitest";

describe("Login", () => {
	describe("isLoginData", () => {
		it("should return false if a required property is missing", () => {
			const fullLoginData: LoginData = {
				password: "some-password",
				username: "Sir User Userly III",
				role: "default",
			};

			let loginData: Partial<LoginData> = {
				...fullLoginData,
			};
			delete loginData.password;
			expect(isLoginData(loginData)).to.be.false;

			loginData = {
				...fullLoginData,
			};
			delete loginData.username;
			expect(isLoginData(loginData)).to.be.false;

			loginData = {
				...fullLoginData,
			};
			delete loginData.role;
			expect(isLoginData(loginData)).to.be.false;
		});

		it("should return false if there are extra properties", () => {
			const fullLoginData: LoginData & { extra: "property" } = {
				password: "some-password",
				username: "Sir User Userly III",
				role: "default",
				extra: "property",
			};

			expect(isLoginData(fullLoginData)).to.be.false;
		});

		it("should return true if the provided target is a Login", () => {
			const fullLoginData: LoginData = {
				password: "some-password",
				username: "Sir User Userly III",
				role: "default",
			};

			expect(isLoginData(fullLoginData)).to.be.true;
		});
	});

	describe("hashPassword", () => {
		it("should hash a password", async () => {
			const pass = "some-password";
			const hash = hashPassword(pass);

			expect(hash).to.not.equal(pass);
		});
	});
});
