import { isServerResponse } from "$lib/ServerResponse";
import { describe, expect, it } from "vitest";

describe("ServerResponse", () => {
	describe("isServerResponse", () => {
		it("should return false no optional property exists", () => {
			const emptyResponse = {};

			expect(isServerResponse(emptyResponse)).to.be.false;
		});

		it("should return false if more than one property is present", () => {
			const overstuffedResponse = {
				item: {},
				error: "something is wrong",
			};

			expect(isServerResponse(overstuffedResponse)).to.be.false;
		});

		it("should return false if there is an unkown property", () => {
			const gibberishServerResponse = {
				some: "gibberish",
			};

			expect(isServerResponse(gibberishServerResponse)).to.be.false;
		});

		it("should return true when target is a proper server response", () => {
			const singleServerResponse = {
				item: {},
			};

			const listServerResponse = {
				items: [],
			};

			const errorServerResponse = {
				error: "something is wrong",
			};

			const accessTokenResponse = {
				access_token: "Bearer somekindoftokenfromtheserver",
			};

			expect(isServerResponse(singleServerResponse)).to.be.true;
			expect(isServerResponse(listServerResponse)).to.be.true;
			expect(isServerResponse(errorServerResponse)).to.be.true;
			expect(isServerResponse(accessTokenResponse)).to.be.true;
		});
	});
});
