import type { GameData } from "$lib/GameData";
import { getGameEvent, isGameEventData } from "$lib/GameEvent";
import { isListing } from "$lib/Listing";
import { updateListing } from "$lib/server/modifyListing";
import { createNewListing } from "$lib/server/modifyListing";
import { writeNewListing } from "$lib/server/mongo";
import {
	readListingById,
	ServerCollections,
	writeUpdatedListing,
} from "$lib/server/mongo";
import { getBody, getParam, getUser, ResourceId } from "$lib/server/requestTools";
import {
	badRequestResponse,
	createdResponse,
	notFoundResponse,
	singleResponse,
} from "$lib/server/responseBodies";
import type { RequestHandler } from "@sveltejs/kit";

export const POST: RequestHandler = async ({
	locals,
	params,
	request,
}): Promise<Response> => {
	const id = getParam(params, ResourceId.Game);

	if (id === null) {
		return badRequestResponse("missing gameid parameter");
	}

	const body = await getBody(request, isGameEventData);

	if (!body) {
		return badRequestResponse("missing game event in body");
	}

	const user = getUser(locals);
	const game = await readListingById(ServerCollections.Games, id, isListing<GameData>);

	if (!game) {
		return notFoundResponse();
	}

	const { state } = game.data;
	const event = getGameEvent(game.data, body);

	try {
		event.run(state);
		game.data.isStarted = true;
	} catch (err) {
		return badRequestResponse(`illegal turn: ${err}`);
	}

	await writeNewListing(ServerCollections.Turns, createNewListing(body));
	await writeUpdatedListing(ServerCollections.Games, updateListing(game, game.data));

	return singleResponse(game);
};
