import { isGameData, type GameData } from "$lib/GameData";
import { isListing } from "$lib/Listing";
import { isServerResponse } from "$lib/ServerResponse";
import { error } from "@sveltejs/kit";
import type { PageServerLoad } from "./$types";

export const load: PageServerLoad = async ({ fetch, params, cookies }) => {
	const url = `/api/games/${params.gameid}`;
	let res: Response;
	let body: unknown;

	const token = cookies.get("access_token");

	if (!token) {
		error(401);
	}

	try {
		res = await fetch(url, { headers: [["Authorization", token]] });
		body = await res.json();
	} catch (err) {
		error(500, "unable to call API");
	}

	if (res.status === 404) {
		error(404, `Not Found: ${params.gameid}`);
	}

	if (!isServerResponse(body)) {
		error(500, "expected to receive a properly formatted server response body");
	}

	if ("item" in body && isListing<GameData>(body.item, isGameData)) {
		return { game: body.item };
	} else {
		error(res.status, "unable to fetch game data");
	}
};
