import { isGameData, type GameData } from "$lib/GameData";
import { isListing, type Listing } from "$lib/Listing";
import { isServerResponse } from "$lib/ServerResponse";
import { error } from "@sveltejs/kit";

export async function getPageData(
	svelteKitFetch: typeof fetch,
	token: string,
): Promise<{ games: Listing<GameData>[] }> {
	const url = "/api/games";
	let res: Response;
	let body: unknown;

	try {
		res = await svelteKitFetch(url, {
			headers: [["Authorization", token]],
		});
		body = await res.json();
	} catch (err) {
		console.log(err);
		error(500, "unable to call API");
	}

	if (res.status === 404) {
		error(404, `Not Found`);
	}

	if (!isServerResponse(body)) {
		console.log("wasn't server response");
		error(500, "expected to receive a properly formatted server response body");
	}

	if ("items" in body) {
		if (
			body.items.reduce((result, item) => {
				if (result) {
					return isListing<GameData>(item, isGameData);
				}

				return false;
			}, true)
		) {
			return { games: body.items as Listing<GameData>[] };
		} else {
			error(500, "malformed API response");
		}
	} else {
		error(res.status, "unable to fetch game data");
	}
}
